@@ -346,11 +346,13 @@ class ezfuc(object):
             file_name = path + file_name
         workbook = xlsxwriter.Workbook(file_name)
         sheet = workbook.add_worksheet('Sheet1')  # 创建一个sheet表格
+
+        l = 0
+        if not isinstance(resList[-1], list):
+            resList = [list(i.values()) for i in resList]
         if title:
             resList.insert(0, title)
-        l = 0
-        if not isinstance(resList, list):
-            resList = [list(i.values()) for i in resList]
+        print(resList)
         for line in tqdm(resList, ascii=True, desc=excel_name):
             r = 00
             for i in line:
